@@ -9,7 +9,7 @@
  * source code.
  */
 /*
-   This example shows how to use instructions, i.e., comedi_insns.  
+   This example shows how to use instructions, i.e., comedi_insns.
 
    Using instructions directly, as in this example, is not recommended
    for the beginner.  Use the higher-level functions such as
@@ -47,23 +47,25 @@ int main(int argc, char *argv[])
 	comedi_insnlist il;
 	struct timeval t1,t2;
 	lsampl_t data[MAX_SAMPLES];
+	struct parsed_options options;
 
-	n_scan = 10;	/* override default n_scan value to something more suitable */
-	parse_options(argc,argv);
-	if( n_scan > MAX_SAMPLES ){
+	init_parsed_options(&options);
+	options.n_scan = 10;	/* override default n_scan value to something more suitable */
+	parse_options(&options, argc, argv);
+	if(options.n_scan > MAX_SAMPLES ){
 		fprintf( stderr, "Requested too many samples, reducing to %i\n", MAX_SAMPLES );
-		n_scan = MAX_SAMPLES;
+		options.n_scan = MAX_SAMPLES;
 	}
 
-	device=comedi_open(filename);
+	device = comedi_open(options.filename);
 	if(!device){
-		comedi_perror(filename);
-		exit(0);
+		comedi_perror(options.filename);
+		exit(-1);
 	}
 
-	if(verbose){
+	if(options.verbose){
 		printf("measuring device=%s subdevice=%d channel=%d range=%d analog reference=%d\n",
-			filename,subdevice,channel,range,aref);
+			options.filename, options.subdevice, options.channel, options.range, options.aref);
 	}
 
 	/* Set up a the "instruction list", which is just a pointer
@@ -79,10 +81,10 @@ int main(int argc, char *argv[])
 
 	/* Instruction 1: do 10 analog input reads */
 	insn[1].insn=INSN_READ;
-	insn[1].n=n_scan;
+	insn[1].n = options.n_scan;
 	insn[1].data=data;
-	insn[1].subdev=subdevice;
-	insn[1].chanspec=CR_PACK(channel,range,aref);
+	insn[1].subdev = options.subdevice;
+	insn[1].chanspec=CR_PACK(options.channel, options.range, options.aref);
 
 	/* Instruction 2: perform a gettimeofday() */
 	insn[2].insn=INSN_GTOD;
@@ -91,18 +93,18 @@ int main(int argc, char *argv[])
 
 	ret=comedi_do_insnlist(device,&il);
 	if(ret<0){
-		comedi_perror(filename);
-		exit(0);
+		comedi_perror(options.filename);
+		exit(-1);
 	}
 
-	printf("initial time: %ld.%06ld\n",t1.tv_sec,t1.tv_usec);
-	for(i=0;i<n_scan;i++){
-		printf("%d\n",data[i]);
+	printf("initial time: %ld.%06ld\n", t1.tv_sec, t1.tv_usec);
+	for(i = 0; i < options.n_scan; i++){
+		printf("%d\n", data[i]);
 	}
-	printf("final time: %ld.%06ld\n",t2.tv_sec,t2.tv_usec);
+	printf("final time: %ld.%06ld\n", t2.tv_sec, t2.tv_usec);
 
-	printf("difference (us): %ld\n",(t2.tv_sec-t1.tv_sec)*1000000+
-			(t2.tv_usec-t1.tv_usec));
+	printf("difference (us): %ld\n",(t2.tv_sec-t1.tv_sec) * 1000000 +
+			(t2.tv_usec - t1.tv_usec));
 
 	return 0;
 }
