@@ -6,7 +6,7 @@
     Copyright (C) 1998-2002 David A. Schleef <ds@schleef.org>
 
     This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
+    it under the terms of the GNU Lesser General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
@@ -82,8 +82,8 @@ enum comedi_oor_behavior comedi_set_global_oor_behavior(enum comedi_oor_behavior
 int comedi_get_n_subdevices(comedi_t *it);
 #define COMEDI_VERSION_CODE(a,b,c) (((a)<<16) | ((b)<<8) | (c))
 int comedi_get_version_code(comedi_t *it);
-char *comedi_get_driver_name(comedi_t *it);
-char *comedi_get_board_name(comedi_t *it);
+const char *comedi_get_driver_name(comedi_t *it);
+const char *comedi_get_board_name(comedi_t *it);
 int comedi_get_read_subdevice(comedi_t *dev);
 int comedi_get_write_subdevice(comedi_t *dev);
 
@@ -141,10 +141,16 @@ int comedi_data_write(comedi_t *it,unsigned int subd,unsigned int chan,
 	unsigned int range,unsigned int aref,lsampl_t data);
 int comedi_dio_config(comedi_t *it,unsigned int subd,unsigned int chan,
 	unsigned int dir);
+int comedi_dio_get_config(comedi_t *it,unsigned int subd,unsigned int chan,
+	unsigned int *dir);
 int comedi_dio_read(comedi_t *it,unsigned int subd,unsigned int chan,
 	unsigned int *bit);
 int comedi_dio_write(comedi_t *it,unsigned int subd,unsigned int chan,
 	unsigned int bit);
+int comedi_dio_bitfield2(comedi_t *it,unsigned int subd,
+	unsigned int write_mask, unsigned int *bits, unsigned int base_channel);
+/* Should be moved to _COMEDILIB_DEPRECATED once bindings for other languages are updated
+ * to use comedi_dio_bitfield2() instead.*/
 int comedi_dio_bitfield(comedi_t *it,unsigned int subd,
 	unsigned int write_mask, unsigned int *bits);
 
@@ -158,7 +164,7 @@ int comedi_sv_measure(comedi_sv_t *it,double *data);
 int comedi_get_cmd_src_mask(comedi_t *dev,unsigned int subdevice,
 	comedi_cmd *cmd);
 int comedi_get_cmd_generic_timed(comedi_t *dev,unsigned int subdevice,
-	comedi_cmd *cmd,unsigned int ns);
+	comedi_cmd *cmd, unsigned chanlist_len, unsigned scan_period_ns);
 int comedi_cancel(comedi_t *it,unsigned int subdevice);
 int comedi_command(comedi_t *it,comedi_cmd *cmd);
 int comedi_command_test(comedi_t *it,comedi_cmd *cmd);
@@ -171,6 +177,8 @@ int comedi_set_max_buffer_size(comedi_t *it, unsigned int subdev,
 int comedi_get_buffer_contents(comedi_t *it, unsigned int subdev);
 int comedi_mark_buffer_read(comedi_t *it, unsigned int subdev,
 	unsigned int bytes);
+int comedi_mark_buffer_written(comedi_t *it, unsigned int subdev,
+	unsigned int bytes);
 int comedi_get_buffer_offset(comedi_t *it, unsigned int subdev);
 
 #ifdef _COMEDILIB_DEPRECATED
@@ -201,6 +209,18 @@ typedef struct
 	unsigned int channel;
 	unsigned int value;
 } comedi_caldac_t;
+#define COMEDI_MAX_NUM_POLYNOMIAL_COEFFICIENTS 4
+typedef struct
+{
+	double coefficients[COMEDI_MAX_NUM_POLYNOMIAL_COEFFICIENTS];
+	double expansion_origin;
+	unsigned order;
+} comedi_polynomial_t;
+typedef struct
+{
+	comedi_polynomial_t *to_phys;
+	comedi_polynomial_t *from_phys;
+} comedi_softcal_t;
 #define CS_MAX_AREFS_LENGTH 4
 typedef struct
 {
@@ -213,6 +233,7 @@ typedef struct
 	unsigned int num_arefs;
 	comedi_caldac_t *caldacs;
 	unsigned int num_caldacs;
+	comedi_softcal_t soft_calibration;
 } comedi_calibration_setting_t;
 
 typedef struct
@@ -231,7 +252,24 @@ void comedi_cleanup_calibration( comedi_calibration_t *calibration );
 int comedi_apply_calibration( comedi_t *dev, unsigned int subdev, unsigned int channel,
 	unsigned int range, unsigned int aref, const char *cal_file_path);
 
-
+/* New stuff to provide conversion between integers and physical values that
+* can support software calibrations. */
+enum comedi_conversion_direction
+{
+	COMEDI_TO_PHYSICAL,
+	COMEDI_FROM_PHYSICAL
+};
+int comedi_get_softcal_converter(
+	unsigned subdevice, unsigned channel, unsigned range,
+	enum comedi_conversion_direction direction,
+	const comedi_calibration_t *calibration, comedi_polynomial_t* polynomial);
+int comedi_get_hardcal_converter(
+	comedi_t *dev, unsigned subdevice, unsigned channel, unsigned range,
+	enum comedi_conversion_direction direction, comedi_polynomial_t* polynomial);
+double comedi_to_physical(lsampl_t data,
+	const comedi_polynomial_t *conversion_polynomial);
+lsampl_t comedi_from_physical(double data,
+	const comedi_polynomial_t *conversion_polynomial);
 
 #endif
 
