@@ -54,7 +54,7 @@ int _comedi_get_version_code(comedi_t *it)
 }
 
 EXPORT_ALIAS_DEFAULT(_comedi_get_driver_name,comedi_get_driver_name,0.7.18);
-char* _comedi_get_driver_name(comedi_t *it)
+const char* _comedi_get_driver_name(comedi_t *it)
 {
 	if(!valid_dev(it))
 		return NULL;
@@ -63,7 +63,7 @@ char* _comedi_get_driver_name(comedi_t *it)
 }
 
 EXPORT_ALIAS_DEFAULT(_comedi_get_board_name,comedi_get_board_name,0.7.18);
-char* _comedi_get_board_name(comedi_t *it)
+const char* _comedi_get_board_name(comedi_t *it)
 {
 	if(!valid_dev(it))
 		return NULL;
@@ -71,15 +71,39 @@ char* _comedi_get_board_name(comedi_t *it)
 	return it->devinfo.board_name;
 }
 
-EXPORT_ALIAS_DEFAULT(_comedi_get_subdevice_flags,comedi_get_subdevice_flags,0.7.18);
-int _comedi_get_subdevice_flags(comedi_t *it,unsigned int subd)
+EXPORT_ALIAS_VER(_comedi_get_subdevice_flags_old, comedi_get_subdevice_flags,0.7.18);
+int _comedi_get_subdevice_flags_old(comedi_t *it,unsigned int subd)
 {
 	if(!valid_dev(it))
 		return 0;
-
 	return it->subdevices[subd].subd_flags;
 }
 
+EXPORT_ALIAS_DEFAULT(_comedi_get_subdevice_flags,comedi_get_subdevice_flags,0.8.0);
+int _comedi_get_subdevice_flags(comedi_t *it,unsigned int subd)
+{
+	comedi_subdinfo *s;
+	int flags;
+	int ret;
+	if(!valid_dev(it))
+		return -1;
+	s = malloc(sizeof(comedi_subdinfo) * it->n_subdevices);
+	if(s == NULL)
+	{
+		__comedi_errno = errno;
+		return -1;
+	}
+	ret = comedi_ioctl(it->fd, COMEDI_SUBDINFO, (unsigned long)s);
+	if(ret < 0)
+	{
+		free(s);
+		return -1;
+	}
+	flags = s[subd].subd_flags;
+	free(s);
+	return flags;
+}
+
 EXPORT_ALIAS_DEFAULT(_comedi_get_subdevice_type,comedi_get_subdevice_type,0.7.18);
 int _comedi_get_subdevice_type(comedi_t *it,unsigned int subd)
 {
